Tutorials
=========

This folder contains interactive tutorials that demonstrate how to build sushi chefs.

  - [quickstart](quikstart.ipynb) : basic steps for creating a channel from the README
  - [languages](languages.ipynb): examples of how to work with the internal language codes
  - [exercises](exercises.ipynb): examples of exercise questions types supported by ricecooker
  - nodes [TODO]
  - files [TODO]


Install
-------

    pip install jupyter

then run

    jupyter notebook

and go to the directory `docs/tutorial/` to see the notebooks


